@@ -14,20 +14,21 @@
 #' @param separateAnnot (logical) separate annotation form numeric data (quantCol and annotCol must be defined)
 #' @param refLi (integer) custom decide which line of data is main species, if single character entry it will be used to choose a group of species (eg 'mainSpe')
 #' @param plotGraph (logical or matrix of integer) optional plot vioplot of initial data; if integer, it will be passed to \code{layout} when plotting
-#' @param graphTit (character) optional title to graph (if \code{plotGraph=TRUE})
+#' @param tit (character) custom title to plot
+#' @param graphTit (character) (depreciated custom title to plot), please use 'tit'
 #' @param silent (logical) suppress messages
 #' @param callFrom (character) allow easier tracking of message(s) produced
 #' @return list with \code{$annot}, \code{$raw} and optional \code{$quant}, or returns data.frame with entire content of file if \code{separateAnnot=FALSE}
 #' @seealso \code{\link[utils]{read.table}} 
 #' @examples
-#' path1 <- system.file("extdata",package="wrProteo")
+#' path1 <- system.file("extdata", package="wrProteo")
 #' fiNa <- "exampleProlineABC.csv"
 #' dataABC <- readProlineFile(file.path(path1,fiNa))
 #' summary(dataABC$quant)
-#' matrixNAinspect(dataABC$quant,gr=as.factor(substr(colnames(dataABC$quant),1,1))) 
+#' matrixNAinspect(dataABC$quant, gr=as.factor(substr(colnames(dataABC$quant),1,1))) 
 #' @export
 readProlineFile <- function(fileName,path=NULL,logConvert=TRUE,quantCol="^abundance_",annotCol=c("accession","description","is_validated","coverage","X.sequences","X.peptides","protein_set.score"), 
-  refLi=NULL,separateAnnot=TRUE,plotGraph=TRUE,graphTit=NULL,silent=FALSE,callFrom=NULL){
+  refLi=NULL,separateAnnot=TRUE,plotGraph=TRUE,tit=NULL,graphTit=NULL,silent=FALSE,callFrom=NULL){
   ## 'quantCol', 'annotCol' (character) exact col-names or if length=1 pattern to search among col-names for $quant or $annot
   fxNa <- wrMisc::.composeCallName(callFrom,newNa="readProlineFile")
   opar <- graphics::par(no.readonly=TRUE)
@@ -52,31 +53,45 @@ readProlineFile <- function(fileName,path=NULL,logConvert=TRUE,quantCol="^abunda
     if(any(all(is.na(quantCol)),all(is.na(annotCol)))) separateAnnot <- FALSE
   }
   metaCo <- wrMisc::naOmit(if(length(annotCol) >1) wrMisc::extrColsDeX(out,extrCol=annotCol,doExtractCols=FALSE,callFrom=fxNa) else grep(annotCol,colnames(out)))
+  ## locate & extract abundance/quantitation data
   if(length(quantCol) >1) { abund <- as.matrix(wrMisc::extrColsDeX(out,extrCol=quantCol,doExtractCols=TRUE,callFrom=fxNa))
   } else {
-    quantCol <-  grep(quantCol,colnames(out)) 
+    quantCol <- grep(quantCol,colnames(out)) 
     chNa <- is.na(quantCol)
     if(all(chNa)) stop("Could not find any of of the columns specified in argument 'quantCol' !")
     if(any(chNa)) { 
       if(!silent) message(fxNa," Could not find columns ",wrMisc::pasteC(quantCol[which(chNa)],quote="'")," .. omit")
       quantCol <- wrMisc::naOmit(quantCol)} 
     abund <- as.matrix(out[,quantCol]) }           # abundance val
-  ## locate & extract abundance/quantitation data
+  ## check abundance/quantitation data
   chNum <- is.numeric(abund)
   if(!chNum) {abund <- apply(out[,quantCol],2,wrMisc::convToNum,convert="allChar",callFrom=fxNa)}    
   if(is.character(refLi) & length(refLi)==1) refLi <- which(out[,"Spec"]==refLi)   # may be "mainSpe"
-  ## don't normalize here by default since data are typically sufficieltly normalized  
+  ## don't normalize here by default since data are typically sufficielntly normalized  
   colnames(abund) <- wrMisc::.trimFromStart(wrMisc::.trimFromEnd(colnames(abund)))
   ## plot distribution of intensities
+  custLay <- NULL
   if(length(plotGraph) >0) {if(is.numeric(plotGraph)) {custLay <- plotGraph; plotGraph <- TRUE
-    } else  {plotGraph <- as.logical(plotGraph[1])}}
-  if(plotGraph) {
+    } else { plotGraph <- as.logical(plotGraph[1])}}
+  if(plotGraph){
+    if(length(custLay) >0) graphics::layout(custLay)
     graphics::par(mar=c(3, 3, 3, 1))                          # mar: bot,le,top,ri
-    if(is.null(graphTit)) graphTit <- "Distribution of quantification values"
-    graphics::boxplot(log2(abund),main=graphTit,las=1,outline=FALSE) 
-    graphics::abline(h=round(log2(stats::median(abund,na.rm=TRUE)))+c(-1,0,1),lty=2,col=grDevices::grey(0.6))
-    on.exit(graphics::par(opar))
-  }  
+    if(length(graphTit) >0) message(fxNa,"argument 'graphTit' is depreciated, please rather use 'tit' ")
+    if(is.null(tit) & !is.null(graphTit)) tit <- graphTit
+    if(is.null(tit)) tit <- "Distribution of quantification values"
+    chGr <- try(find.package("wrGraph"), silent=TRUE)
+    chSm <- try(find.package("sm"), silent=TRUE)
+    misPa <- c("try-error" %in% class(chGr),"try-error" %in% class(chSm))
+    if(any(misPa)) { 
+      if(!silent) message(fxNa," missing package ",wrMisc::pasteC(c("wrGraph","sm")[which(misPa)],quoteC="'")," for drawing vioplots")
+      ## wrGraph not available : simple boxplot  
+      graphics::boxplot(log2(abund),main=tit,las=1,outline=FALSE) 
+      graphics::abline(h=round(log2(stats::median(abund,na.rm=TRUE)))+c(-1:1),lty=2,col=grDevices::grey(0.6))      
+    } else {                                          # wrGraph & sm are available
+      wrGraph::vioplotW(log2(abund),tit=paste(tit," (initial)",sep=" ")) 
+      graphics::abline(h=round(stats::median(abund,na.rm=TRUE))+(-1:1),lty=2,col=grDevices::grey(0.6))           
+    }
+    on.exit(graphics::par(opar)) }   #
   ##
   if(separateAnnot) {
     if(!is.numeric(abund) & logConvert) {message(fxNa," Problem: Abundance data seem not numeric, can't transform log2 !")}
@@ -88,5 +103,6 @@ readProlineFile <- function(fileName,path=NULL,logConvert=TRUE,quantCol="^abunda
         if(!silent) message(fxNa," NOTE : ",length(ch0)," elements of '",fileName,"' are 0 or negative, will be transformed to NA for log2 transformation")}
       out$quant <- log2(out$quant) }
     }
+  ## final  
   out }
    
